@@ -1,6 +1,6 @@
 package DBIx::Class::DeploymentHandler::LogImporter;
 {
-  $DBIx::Class::DeploymentHandler::LogImporter::VERSION = '0.002206';
+  $DBIx::Class::DeploymentHandler::LogImporter::VERSION = '0.002207';
 }
 
 use warnings;
@@ -8,13 +8,12 @@ use strict;
 
 use parent 'Log::Contextual';
 
-use DBIx::Class::DeploymentHandler::Logger;
+use DBIx::Class::DeploymentHandler::LogRouter;
 
-my $logger = DBIx::Class::DeploymentHandler::Logger->new({
-   env_prefix => 'DBICDH'
-});
-
-sub arg_package_logger { $_[1] || $logger }
+{
+   my $router;
+   sub router { $router ||= DBIx::Class::DeploymentHandler::LogRouter->new }
+}
 
 1;
 
