@@ -1,6 +1,6 @@
 package DBIx::Class::DeploymentHandler::Logger;
 {
-  $DBIx::Class::DeploymentHandler::Logger::VERSION = '0.002206';
+  $DBIx::Class::DeploymentHandler::Logger::VERSION = '0.002207';
 }
 
 use warnings;
@@ -40,6 +40,15 @@ sub _log {
   warn "[DBICDH] [$level] $message";
 }
 
+sub new {
+   my ($self, $options, @rest) = @_;
+
+   $options ||= {};
+   $options->{env_prefix} ||= 'DBICDH';
+
+   $self->next::method($options, @rest)
+}
+
 1;
 
 __END__
